%define anolis_release 1
%global pypi_name packaging

# Specify --with bootstrap to build in bootstrap mode
# This mode is needed, because python3-rpm-generators need packaging
# When bootstrapping, disable tests and docs as well.
%bcond_with bootstrap

%if %{without bootstrap}
# Specify --without docs to prevent the dependency loop on python-sphinx
%bcond_without docs

# Specify --without tests to prevent the dependency loop on python-pytest
%bcond_without tests
%else
%bcond_with docs
%bcond_with tests
%endif

Name:           python-%{pypi_name}
Version:        22.0
Release:        %{anolis_release}%{?dist}
Summary:        Core utilities for Python packages

License:        BSD or ASL 2.0
URL:            https://github.com/pypa/packaging
Source0:        %{url}/archive/refs/tags/%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  pyproject-rpm-macros

%if %{with bootstrap}
BuildRequires:  python%{python3_pkgversion}-setuptools
%endif

# Upstream uses nox for testing, we specify the test deps manually as well.
%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-pretend
%endif
%if %{with docs}
BuildRequires:  python%{python3_pkgversion}-sphinx
%endif

%global _description %{expand:
python-packaging provides core utilities for Python packages like utilities for
dealing with versions, specifiers, markers etc.}

%description %_description


%package -n python%{python3_pkgversion}-%{pypi_name}
Summary:        %{summary}

%py_provides    python%{python3_pkgversion}-%{pypi_name}

%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(packaging) = %{version}
Provides:       python%{python3_version}dist(packaging) = %{version}
Requires:       python%{python3_version}dist(pyparsing)
Requires:       python(abi) = %{python3_version}
%endif

%description -n python%{python3_pkgversion}-%{pypi_name}  %_description

%if %{with docs}
%package -n python%{python3_pkgversion}-%{pypi_name}-doc
Summary:        Documentation files for python%{python3_pkgversion}-%{pypi_name}
Requires:       python%{python3_pkgversion}-%{pypi_name} = %{version}-%{release}
BuildArch:      noarch

%description -n python%{python3_pkgversion}-%{pypi_name}-doc
Documentation for python%{python3_pkgversion}-%{pypi_name}.
%endif

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Do not use furo as HTML theme in docs
# furo is not available in Fedora
sed -i '/html_theme = "furo"/d' docs/conf.py

%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires -r
%endif

%build
%if %{with bootstrap}
%py3_build
%else
%pyproject_wheel
%endif

%if %{with docs}
# generate html docs
sphinx-build-3 docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
# Do not bundle fonts
rm -rf html/_static/fonts/
%endif

%install
%if %{with bootstrap}
%py3_install
echo '%{python3_sitelib}/packaging*' > %{pyproject_files}
%else
%pyproject_install
%pyproject_save_files %{pypi_name}
%endif

%if %{with tests}
%check
# Specified tests don't work on big endian platforms
# Reported in: https://github.com/pypa/packaging/issues/472
%pytest -k "not test_get_musl_version and not test_parse_ld_musl_from_elf_no_interpreter_section and not test_parse_ld_musl_from_elf"
%endif

%files -n python%{python3_pkgversion}-%{pypi_name} -f %{pyproject_files}
%license LICENSE LICENSE.APACHE LICENSE.BSD
%doc README.rst CHANGELOG.rst CONTRIBUTING.rst

%if %{with docs}
%files -n python%{python3_pkgversion}-%{pypi_name}-doc
%doc html
%license LICENSE LICENSE.APACHE LICENSE.BSD
%endif

%changelog
* Tue Jan 03 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 22.0-1
- update to version 22.0

* Mon Apr 18 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 21.3-1
- init from upstream
